//
//  CWPoint.h
//  ResaISkane
//
//  Copyright 2009-2010 Fredrik Olsson. All rights reserved.
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License. 
//  You may obtain a copy of the License at 
// 
//  http://www.apache.org/licenses/LICENSE-2.0 
//  
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS, 
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import <Foundation/Foundation.h>

/*!
 * @abstract Type of point.
 */
typedef enum {
  CWPointTypeStopArea = 0,          //! A buss stop or train station.
  CWPointTypePointOfInterest = 1,   //! A point of interest.
  CWPointTypeAddress = 2            //! A street address.
} CWPointType;

/*!
 * @abstract A start, end or change point for a trip.
 *
 * @discussion A point is identified by it's ID and point type, points of different types could have the same ID.
 *             The name of a point is optional for request to the server.
 */
@interface CWPoint : NSObject <NSCoding> {
@private
  NSUInteger _ID;
  NSString* _name;
  NSString* _stopPoint;
  CWPointType _type;
}

@property(nonatomic, readonly, assign) NSUInteger ID;           //! Numeric ID of point.
@property(nonatomic, readonly, retain) NSString* name;          //! Human readable name of point.
@property(nonatomic, readonly, retain) NSString* stopPoint;     //! Stop point, eg. 'E' or '2' for a point, only used for search results.
@property(nonatomic, readonly, assign) CWPointType type;        //! The stop type of this point.
@property(nonatomic, readonly, retain) NSString* typeString;    //! Human readable stop type of this point.
@property(nonatomic, readonly, retain) NSString* queryString;   //! String to insert into get query URL when searchig for this point.

/*!
 * @abstract An array of default points to add at first start, so the user is not presented with a confusing empty UI.
 */
+(NSMutableArray*)defaultKnownPoints;

/*!
 * @abstract An array of default bookmarks to add at first start, a bookmark a set with two points.
 */
+(NSMutableArray*)defaultJourneySearchBookmarks;

/*!
 * @abstract Fetch an array of points mathcing a string from the server.
 *
 * @discussion You must queue fetches in order to not starve the server. Responses are fast enough for searchingas you type.
 */
+(NSArray*)pointsMatchingString:(NSString*)searchString;

/*!
 * @abstract An image representing the type of point.
 */
-(UIImage*)imageForType;

/*!
 * @abstract An accessory type for this type of view.
 *
 * @discussion Currently unused,, but should be used to return a detail disclosure triangle for points that can have 
 *             real-time information.
 */
-(UITableViewCellAccessoryType)accessoryType;

@end
